@@ -12,7 +12,7 @@
 #' @param header_heading Character string; text that will be used as heading.
 #' @param header_firstinfo Character string; text that will used as first information in the header.
 #' @param insert_arrow_annotationID Integer; ID of the annotation in front of which the arrow will be placed.
-#'
+#' @param collapse Logical; if \code{FALSE} a vector will be created, each element corresponding to one annotation. if \code{TRUE} a single string will be created, collapsed by linebreaks \\n.
 #' @return Character string; transcript as text.
 #' 
 #' @seealso \code{corpus_export}, \code{export_eaf}, \code{export_exb}, \code{export_rpraat}, \code{export_srt}, \code{export_textgrid} 
@@ -29,7 +29,8 @@ export_printtranscript <- function (t,
 									filterSectionEndsec = NULL,  
 									insert_arrow_annotationID = "", 
 									header_heading ="", 
-									header_firstinfo = "") {
+									header_firstinfo = "",
+									collapse=TRUE) {
 	#=== settings
 	if (missing(t)) 	{stop("Transcript object in parameter 't' is missing.") 	} else { if (class(t)[[1]]!="transcript") 	{stop("Parameter 't' needs to be a transcript object.") 	} }
 	if (is.null(l)) 	{
@@ -86,7 +87,12 @@ export_printtranscript <- function (t,
 	#--- filter 
 	t <- act::transcripts_filter_single(t, filterTierNames=filterTierNames, filterSectionStartsec = filterSectionStartsec, filterSectionEndsec = filterSectionEndsec)
 	#--- cure
-	t <- act::transcripts_cure_single(t, annotationsWithReversedTimes=TRUE, overlappingAnnotations=TRUE, annotationsWithTimesBelowZero=FALSE, missingTiers=FALSE, showWarning=TRUE)
+	t <- act::transcripts_cure_single(t, 
+									  annotationsWithReversedTimes=TRUE, 
+									  overlappingAnnotations=TRUE, 
+									  annotationsWithTimesBelowZero=FALSE, 
+									  missingTiers=FALSE, 
+									  showWarning=TRUE)
 
 	#--- get annotations from transcript
 	myAnnotations <- t@annotations
@@ -150,7 +156,6 @@ export_printtranscript <- function (t,
 	#--- take the tier name
 	myAnnotations$speaker <- myAnnotations$tier.name
 	
-	
 	#--- same speaker as before ? --> set to ""
 	myAnnotations_speaker_previous <- c("", myAnnotations$speaker[1:length(myAnnotations$speaker)-1] )
 	sameSpeaker_pos <- myAnnotations_speaker_previous==myAnnotations$speaker
@@ -393,7 +398,6 @@ export_printtranscript <- function (t,
 		} #next i
 	} #if brackets need to be aligned
 	
-	
 	#wrap and build entire text
 	for (i in 1:length(myAnnotations$text)) {
 		
@@ -409,7 +413,7 @@ export_printtranscript <- function (t,
 			text_line <- stringr::str_replace(text_line, searchString, "")
 		}
 		#remove line breaks that will lead to an error
-		searchString <- "\\r?\\n"
+		searchString <- "\\r?\n"
 		text_line <- stringr::str_replace_all(text_line, searchString, "")
 		
 		#wrap
@@ -449,28 +453,26 @@ export_printtranscript <- function (t,
 		}
 		header <- paste(header, t@name , ", ", sep="")
 		
-		if (is.null(filterSectionStartsec)) {
-			header <- paste(header, "0-", sep="")
-		} else {
-			if (filterSectionStartsec<0) {
-				header <- paste(header, "0-", sep="")
-			} else {
-				header <- paste(header, round(filterSectionStartsec, digits=1), "-", sep="")
-			}
-		}
+		timesSTR <- paste(
+			
+			helper_format_time(min(myAnnotations$startSec)), 
+			"-", 
+			helper_format_time(max(myAnnotations$endSec)),
+			" (",
+			stringr::str_replace_all(format(round(min(myAnnotations$startSec), digits=1), nsmall = 1), '\\.', ","),
+					"-", 
+					stringr::str_replace_all(format(round(max(myAnnotations$endSec), digits=1),nsmall = 1), '\\.', ","), 
+					" sec))", sep="")
 		
-		if (is.null(filterSectionEndsec)) {
-			header <- paste(header, round(t@length, digits=0), " sec)\n", sep="")
-		} else {
-			if (filterSectionEndsec<0) {
-				header <- paste(header, round(t@length, digits=0), " sec)\n", sep="")
-			} else {
-				header <- paste(header, round(filterSectionStartsec, digits=1), " sec)\n", sep="")
-			}
-		}
+		header <- paste(header, timesSTR, sep="")
 		output <- c(header, output)
 	}
 	
+	if (collapse) {
+		output <- stringr::str_c(output, sep='\n', collapse = '\n')
+		output <-  stringr::str_c(c(output, '\n'), sep='', collapse = '')
+	}
+	
 	if (is.null(outputPath)) {
 	} else {
 		fileConn <- file(outputPath)
