@@ -5,7 +5,7 @@
 #' This function is to create compatibility with the \code{rPraat} package. 
 #' It converts an act transcript to a rPraat TextGrid object.
 #' 
-#' Credits to Tomáš Bořil, the author of the rPraat package, for commenting on the exchange functions.
+#' Credits: Thanks to Tomáš Bořil, the author of the rPraat package, for commenting on the exchange functions.
 #' 
 #' @param t Transcript object; transcript to be converted.
 #' @param filterTierNames Vector of character strings; names of tiers to be included. If left unspecified, all tiers will be exported.
@@ -46,7 +46,7 @@ export_rpraat <- function(t,
 	
 	#--- get min and max times of textgrid
 	textgrid.startSec <- min(0, myAnnotations$startSec, myAnnotations$endSec)
-	textgrid.endSec   <- max(c(t@length, myAnnotations$startSec, myAnnotations$endSec))
+	textgrid.endSec   <- max(c(t@length.sec, myAnnotations$startSec, myAnnotations$endSec))
 
 	myTG <- list()
 	if (nrow(t@tiers)>0) {
