@@ -6,7 +6,9 @@
 #' Therefore you need to set the path to the ELAN executable in the option 'act.path.elan' using \code{options(act.path.elan='PATHTOYOURELANEXECUTABLE')}.
 #' 
 #' WARNING: This function will overwrite existing .psfx files. 
-#'
+#' 
+#' Credits: Thanks to Han Sloetjes for feedback on the structure of the temporary .pfsx files. He actually made the code work. 
+#' 
 #' @param x Corpus object.
 #' @param s Search object. 
 #' @param resultNr Integer; Number of the search result (row in the data frame \code{s@results}) to be opened.
@@ -116,10 +118,24 @@ search_openresult_inelan  <- function(x,
 	writeBin(charToRaw(pfsx.1), fileConn, endian="little")
 	close(fileConn)
 
+	#wait until pfsx exists
+	for (i in 1:10) {
+		if(file.exists(file.path.pfsx)) {
+		break	
+		}
+		Sys.sleep(0.02)
+	}
+
+	#--- open elan
+	cmd <- sprintf("open -a %s", shQuote(path.elan))
+	rslt <- system(cmd, wait=FALSE)
+
+	system('sleep 1 && ls', wait=FALSE)
+	
 	#--- open eaf file
-	#cmd <- sprintf("open -a ELAN_6.0.app %s", shQuote(file.path.eaf))
 	cmd <- sprintf("open -a %s %s", shQuote(path.elan), shQuote(file.path.eaf))
 	rslt <- system(cmd, wait=FALSE)
 
 	
+	
 }
