@@ -10,4 +10,4 @@ examplecorpus@transcripts[["SYNC_rotar_y_flexionar"]]@media.path
 
 # Get only media files of a certain type, e.g. a wav file, and return only the first match:
 act::media_getPathToExistingFile(examplecorpus@transcripts[["SYNC_rotar_y_flexionar"]],
-                              filterFile=".*\\.wav")
+ filterMediaFile=".*\\.wav")
