@@ -12,7 +12,7 @@ setdiff(names(examplecorpus@transcripts), names(test@transcripts))
 test@history[length(test@history)]
 
 # delete transcripts that match a filter, e.g. all transcripts from Bolivia "BOL_"
-mymeta <- act::search_meta(examplecorpus, filterTranscriptIncludeRegEx = "BOL_")
+mymeta <- act::search_makefilter(examplecorpus, filterTranscriptIncludeRegEx = "BOL_")
 test <- act::transcripts_delete(examplecorpus, 
 mymeta$transcripts.names)
 
