@@ -13,10 +13,10 @@ t2 <- act::transcripts_filter_single(t1, filterTierNames=t1@tiers$name[1])
 t2@tiers
 table(t2@annotations$tier.name)
 
-# Use act::search_meta() first to get the tier names, 
+# Use act::search_makefilter() first to get the tier names, 
 # in this case search for tiers with a capital 'I',
 # which is the second tier, called 'ISanti'
-mymeta <- act::search_meta(examplecorpus, 
+mymeta <- act::search_makefilter(examplecorpus, 
 				filterTranscriptNames=t2@name,
 				filterTierIncludeRegEx="I"
 				)
